# Network Troubleshooting and Debugging Tools Container

This Docker image is based on Alpine Linux and includes a comprehensive suite of network troubleshooting and debugging tools. Additionally, it hosts a small Go program that echoes back HTTP request information in JSON format, ideal for debugging and inspecting incoming requests.

## Tools Included
- Common network utilities (`ip`, `netstat`, `route`, `nmap`, `nc`, `socat`, etc.)
- DNS utilities (`dig`, `nslookup`)
- Network monitoring tools (`nethogs`, `iftop`, `mtr`, `traceroute`, `tcpdump`)
- `jq` for JSON processing
- Custom Go program to echo HTTP requests

## Running the Container

To run the container on port 8080, use the following command:

```bash
docker run -d --rm --name nshoot -p 8080:80 rbehzadan/nshoot
```

## Using the Container

Once running, you can execute commands within the container to debug network issues.
```bash
$ docker exec -it nshoot sh
```

For example, to access the Go echo server:
```bash
$ curl -s localhost:8080 | jq
{
  "url": "/",
  "method": "GET",
  "query_params": {},
  "headers": {
    "Accept": [
      "*/*"
    ],
    "User-Agent": [
      "curl/8.7.1"
    ]
  },
  "cookies": {},
  "body": "",
  "user_agent": "curl/8.7.1",
  "remote_addr": "172.17.0.1:43652",
  "host": "localhost:8080",
  "referer": "",
  "content_length": 0,
  "content_type": "",
  "server_time": "2024-04-25T22:46:47Z",
  "server_timestamp_utc": 1714085207,
  "onewaytrip_ms": -1,
  "roundtrip_ms": -1,
  "server_hostname": "8fa30ff94798",
  "server_local_ip": "172.17.0.2",
  "server_version": "1.0.0"
}
```

## License

This project is licensed under the MIT License.

